==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/UIAlertViewDelegate.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/UIAlertViewDelegate/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<methods>*/
    /**
     * @since Available in iOS 2.0 and later.
     * @deprecated Deprecated in iOS 9.0.
     */
    @Deprecated
    @Method(selector = "alertView:clickedButtonAtIndex:")
    void clicked(UIAlertView alertView, @MachineSizedSInt long buttonIndex);
    /**
     * @since Available in iOS 2.0 and later.
     * @deprecated Deprecated in iOS 9.0.
     */
    @Deprecated
    @Method(selector = "alertViewCancel:")
    void cancel(UIAlertView alertView);
    /**
     * @since Available in iOS 2.0 and later.
     * @deprecated Deprecated in iOS 9.0.
     */
    @Deprecated
    @Method(selector = "willPresentAlertView:")
    void willPresent(UIAlertView alertView);
    /**
     * @since Available in iOS 2.0 and later.
     * @deprecated Deprecated in iOS 9.0.
     */
    @Deprecated
    @Method(selector = "didPresentAlertView:")
    void didPresent(UIAlertView alertView);
    /**
     * @since Available in iOS 2.0 and later.
     * @deprecated Deprecated in iOS 9.0.
     */
    @Deprecated
    @Method(selector = "alertView:willDismissWithButtonIndex:")
    void willDismiss(UIAlertView alertView, @MachineSizedSInt long buttonIndex);
    /**
     * @since Available in iOS 2.0 and later.
     * @deprecated Deprecated in iOS 9.0.
     */
    @Deprecated
    @Method(selector = "alertView:didDismissWithButtonIndex:")
    void didDismiss(UIAlertView alertView, @MachineSizedSInt long buttonIndex);
    /**
     * @since Available in iOS 2.0 and later.
     * @deprecated Deprecated in iOS 9.0.
     */
    @Deprecated
    @Method(selector = "alertViewShouldEnableFirstOtherButton:")
    boolean shouldEnableFirstOtherButton(UIAlertView alertView);
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/uikit/UIAlertViewDelegate.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/UIAlertViewDelegate/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<methods>*/
    /**
     * @deprecated Deprecated in iOS 9.0. Use UIAlertController instead.
     */
    @Deprecated
    @Method(selector = "alertView:clickedButtonAtIndex:")
    void clicked(UIAlertView alertView, @MachineSizedSInt long buttonIndex);
    /**
     * @deprecated Deprecated in iOS 9.0. Use UIAlertController instead.
     */
    @Deprecated
    @Method(selector = "alertViewCancel:")
    void cancel(UIAlertView alertView);
    /**
     * @deprecated Deprecated in iOS 9.0. Use UIAlertController instead.
     */
    @Deprecated
    @Method(selector = "willPresentAlertView:")
    void willPresent(UIAlertView alertView);
    /**
     * @deprecated Deprecated in iOS 9.0. Use UIAlertController instead.
     */
    @Deprecated
    @Method(selector = "didPresentAlertView:")
    void didPresent(UIAlertView alertView);
    /**
     * @deprecated Deprecated in iOS 9.0. Use UIAlertController instead.
     */
    @Deprecated
    @Method(selector = "alertView:willDismissWithButtonIndex:")
    void willDismiss(UIAlertView alertView, @MachineSizedSInt long buttonIndex);
    /**
     * @deprecated Deprecated in iOS 9.0. Use UIAlertController instead.
     */
    @Deprecated
    @Method(selector = "alertView:didDismissWithButtonIndex:")
    void didDismiss(UIAlertView alertView, @MachineSizedSInt long buttonIndex);
    /**
     * @deprecated Deprecated in iOS 9.0. Use UIAlertController instead.
     */
    @Deprecated
    @Method(selector = "alertViewShouldEnableFirstOtherButton:")
    boolean shouldEnableFirstOtherButton(UIAlertView alertView);
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}
